@@ -366,7 +366,7 @@ class pts_client
 
 				foreach($system_log_files as $file)
 				{
-					if(is_file($file) && is_readable($file))
+					if(is_file($file) && is_readable($file) && filesize($file) < 1000000)
 					{
 						// copy() can't be used in this case since it will result in a blank file for /proc/ file-system
 						$file_contents = file_get_contents($file);
@@ -412,6 +412,13 @@ class pts_client
 					{
 						$cmd_output = shell_exec('cd ' . dirname($command_bin) . ' && ./' . $command_string . ' 2>&1');
 
+						if(strlen($cmd_output) > 900000)
+						{
+							// Don't preserve really large logs, likely filled with lots of junk
+							$cmd_output = null;
+							continue;
+						}
+
 						// Try to filter out any serial numbers, etc.
 						phodevi_vfs::cleanse_file($cmd_output, $command[0]);
 						$cmd_output = pts_strings::remove_line_timestamps($cmd_output);
@@ -454,6 +461,8 @@ class pts_client
 					}
 					file_put_contents($system_log_dir . 'environment-variables', $variable_dump);
 				}
+
+				pts_module_manager::module_process('__post_test_run_system_logs', $system_log_dir);
 			}
 		}
 
@@ -487,7 +496,7 @@ class pts_client
 				break;
 		}
 	}
-	public static function program_requirement_checks($only_show_required = false)
+	public static function program_requirement_checks($only_show_required = false, $always_report = false)
 	{
 		$extension_checks = pts_needed_extensions();
 
@@ -495,14 +504,21 @@ class pts_client
 		$printed_optional_header = false;
 		foreach($extension_checks as $extension)
 		{
-			if($extension[1] == false)
+			if($extension[1] == false || $always_report)
 			{
+				if($always_report)
+				{
+					$printed_required_header = true;
+					$printed_optional_header = true;
+					echo ($extension[1] == false ? 'MISSING' : 'PRESENT') . ' - ';
+				}
+
 				if($extension[0] == 1)
 				{
 					// Oops, this extension is required
 					if($printed_required_header == false)
 					{
-						echo PHP_EOL . 'The following PHP extensions are REQUIRED by the Phoronix Test Suite:' . PHP_EOL . PHP_EOL;
+						echo PHP_EOL . 'The following PHP extensions are REQUIRED:' . PHP_EOL . PHP_EOL;
 						$printed_required_header = true;
 					}
 				}
@@ -521,7 +537,7 @@ class pts_client
 					}
 				}
 
-				echo sprintf('%-8ls %-30ls' . PHP_EOL, $extension[2], $extension[3]);
+				echo sprintf('%-9ls %-30ls' . PHP_EOL, $extension[2], $extension[3]);
 			}
 		}
 
@@ -529,7 +545,7 @@ class pts_client
 		{
 			echo PHP_EOL;
 
-			if($printed_required_header)
+			if($printed_required_header && !$always_report)
 			{
 				exit;
 			}
@@ -914,11 +930,12 @@ class pts_client
 		{
 			if(pts_file_io::mkdir($save_to_dir . '/result-graphs') == false)
 			{
-				// Directory must exist, so remove any old graph files first
+				// Don't delete old files now, in case any modules (e.g. FlameGrapher) output something in there ahead of time
+				/*// Directory must exist, so remove any old graph files first
 				foreach(pts_file_io::glob($save_to_dir . '/result-graphs/*') as $old_file)
 				{
 					unlink($old_file);
-				}
+				}*/
 			}
 		}
 
@@ -1501,7 +1518,7 @@ class pts_client
 				}
 				else
 				{
-					$possible_browsers = array('firefox', 'mozilla', 'x-www-browser', 'open', 'xdg-open', 'iceweasel', 'konqueror', 'epiphany', 'google-chrome', 'midori', 'epiphany-browser', 'epiphany', 'midori');
+					$possible_browsers = array('firefox', 'mozilla', 'x-www-browser', 'iceweasel', 'konqueror', 'epiphany', 'google-chrome', 'midori', 'epiphany-browser', 'epiphany', 'midori', 'qupzilla', 'open', 'xdg-open');
 
 					foreach($possible_browsers as &$b)
 					{
