@@ -168,10 +168,16 @@ class pts_stress_run_manager extends pts_test_run_manager
 
 				$test = new pts_test_profile(file_get_contents($pid_file));
 
-				if(!in_array($test->get_test_hardware_type(), $this->stress_subsystems_active))
+				// Count the number of tests per stress subsystems active
+				if(!isset($this->stress_subsystems_active[$test->get_test_hardware_type()]))
 				{
-					$this->stress_subsystems_active[] = $test->get_test_hardware_type();
+					$this->stress_subsystems_active[$test->get_test_hardware_type()] = 1;
 				}
+				else
+				{
+					$this->stress_subsystems_active[$test->get_test_hardware_type()] += 1;
+				}
+
 				if(!in_array($test->get_identifier(), $test_identifiers_active))
 				{
 					$test_identifiers_active[] = $test->get_identifier();
@@ -191,7 +197,9 @@ class pts_stress_run_manager extends pts_test_run_manager
 					// Try to pick a test for a hardware subsystem not yet being explicitly utilized
 					foreach($possible_tests_to_run as $i => $test)
 					{
-						if(!in_array($test->test_profile->get_test_hardware_type(), $this->stress_subsystems_active))
+						$hw_subsystem_type = $test->test_profile->get_test_hardware_type();
+
+						if(!isset($this->stress_subsystems_active[$hw_subsystem_type]) && !$this->skip_test_check($test))
 						{
 							$test_run_index = $i;
 							$test_to_run = $test;
@@ -205,7 +213,7 @@ class pts_stress_run_manager extends pts_test_run_manager
 					// Try to pick a test from a test profile not currently active
 					foreach($possible_tests_to_run as $i => $test)
 					{
-						if(!in_array($test->test_profile->get_identifier(), $test_identifiers_active))
+						if(!in_array($test->test_profile->get_identifier(), $test_identifiers_active) && !$this->skip_test_check($test))
 						{
 							$test_run_index = $i;
 							$test_to_run = $test;
@@ -219,6 +227,11 @@ class pts_stress_run_manager extends pts_test_run_manager
 					// Last resort, just randomly pick a true "random" test
 					$test_run_index = array_rand(array_keys($possible_tests_to_run));
 					$test_to_run = $possible_tests_to_run[$test_run_index];
+
+					if($this->skip_test_check($test_to_run))
+					{
+						continue;
+					}
 				}
 
 				$pid = pcntl_fork();
@@ -314,6 +327,19 @@ class pts_stress_run_manager extends pts_test_run_manager
 
 		return true;
 	}
+	protected function skip_test_check(&$test)
+	{
+		$hw_subsystem_type = $test->test_profile->get_test_hardware_type();
+		$subsystem_limit_check = getenv('LIMIT_STRESS_' . strtoupper($hw_subsystem_type) . '_TESTS_COUNT');
+
+		if(isset($this->stress_subsystems_active[$hw_subsystem_type]) && $subsystem_limit_check && $subsystem_limit_check <= $this->stress_subsystems_active[$hw_subsystem_type])
+		{
+			// e.g. LIMIT_STRESS_GRAPHICS_TESTS_COUNT=2, don't want more than that number per subsystem concurrently
+			return true;
+		}
+
+		return false;
+	}
 	public function action_on_stress_log_set($call)
 	{
 		if(is_callable($call))
@@ -382,7 +408,7 @@ class pts_stress_run_manager extends pts_test_run_manager
 		$report_buffer .= pts_user_io::display_text_table($table, '   - ', 2) . PHP_EOL;
 
 		$report_buffer .= 'TEST SUBSYSTEMS ACTIVE: ' . PHP_EOL;
-		foreach($this->stress_subsystems_active as &$type)
+		foreach($this->stress_subsystems_active as $type => $count)
 		{
 			$report_buffer .= '   - ' . $type . PHP_EOL;
 		}
