@@ -706,7 +706,20 @@ class phodevi_gpu extends phodevi_device_interface
 				$video_ram *= 1024;
 			}
 		}
+		else
+		{
+			// Try reading video memoty from GLX_MESA_query_renderer output in glxinfo
+			$glxinfo_video_mem = str_replace('MB', null, phodevi_parser::glxinfo_read_line('Video memory'));
 
+			if(is_numeric($glxinfo_video_mem) && $glxinfo_video_mem > 1)
+			{
+				// Do some rounding as at least AMDGPU/RadeonSI reports less than real amount
+				$video_ram = $glxinfo_video_mem % 128 === 0 ? $glxinfo_video_mem : round(($glxinfo_video_mem + 128 / 2) / 128) * 128;
+			}
+		}
+
+		// Disabling 27 Nov 2016 as seems to cause problems with AMDGPU-0PRO but falls back gracefully outside of this xorg-log parsing for correct amount
+		/*
 		if($video_ram == -1 && isset(phodevi::$vfs->xorg_log))
 		{
 			// Attempt Video RAM detection using X log
@@ -730,6 +743,8 @@ class phodevi_gpu extends phodevi_device_interface
 				}
 			}
 		}
+		*/
+
 		if($video_ram == -1 && isset(phodevi::$vfs->dmesg))
 		{
 			// Fallback to try to find vRAM from dmesg
@@ -1278,14 +1293,24 @@ class phodevi_gpu extends phodevi_device_interface
 		{
 			$info = phodevi_windows_parser::read_cpuz('Display Adapters', 'Name');
 		}
-	
+
 		if(empty($info) || strpos($info, 'Mesa ') !== false || strpos($info, 'Gallium ') !== false)
 		{
+			if(($x = strpos($info, ' on ')) !== false)
+			{
+				// to remove section like "Gallium 0.4 on AMD POLARIS"
+				$info = substr($info, $x + 4);
+			}
+			if(($x = strpos($info, ' (')) !== false)
+			{
+				$info = substr($info, 0, $x);
+			}
+
 			if(phodevi::is_windows() == false)
 			{
 				$info_pci = phodevi_linux_parser::read_pci('VGA compatible controller', false);
 
-				if(!empty($info_pci))
+				if(!empty($info_pci) && strpos($info_pci, 'Device ') === false)
 				{
 					$info = $info_pci;
 
@@ -1450,13 +1475,13 @@ class phodevi_gpu extends phodevi_device_interface
 			$info = $vendor . ' ' . $info;
 		}
 
-		if($video_ram > 64 && strpos($info, $video_ram) == false) // assume more than 64MB of vRAM
+		$clean_phrases = array('OpenGL Engine');
+		$info = str_replace($clean_phrases, null, $info);
+
+		if(!empty($info) && $video_ram > 64 && strpos($info, $video_ram) == false) // assume more than 64MB of vRAM
 		{
 			$info .= ' ' . $video_ram . 'MB';
 		}
-	
-		$clean_phrases = array('OpenGL Engine');
-		$info = str_replace($clean_phrases, null, $info);
 
 		return $info;
 	}
