@@ -95,6 +95,7 @@ abstract class pts_graph_core
 		if(isset($extra_attributes['force_tracking_line_graph']))
 		{
 			// Phoromatic result tracker
+			// TODO: investigate this check as it could cause problems... bad assumption to make
 			$this->is_multi_way_comparison = true;
 		}
 		else if(isset($result_object->test_result_buffer))
@@ -234,7 +235,7 @@ abstract class pts_graph_core
 		$config['color']['body_light'] = '#949494';
 		$config['color']['highlight'] = '#005a00';
 		$config['color']['alert'] = '#C80000';
-		$config['color']['paint'] = array('#2196f3', '#f44336', '#673ab7', '#01579b', '#009688', '#4caf50',  '#ffeb3b', '#ff5722', '#e91e63', '#795548', '#9e9e9e', '#607d8b', '#FFB300', '#803E75', '#FF6800', '#A6BDD7', '#C10020', '#CEA262', '#817066', '#007D34', '#F6768E', '#00538A', '#FF7A5C', '#53377A', '#FF8E00', '#B32851', '#F4C800', '#7F180D', '#93AA00', '#593315', '#F13A13', '#232C16');
+		$config['color']['paint'] = array('#2196f3', '#f44336', '#673ab7', '#01579b', '#009688', '#4caf50', '#ff5722', '#e91e63', '#795548', '#9e9e9e', '#607d8b', '#FFB300', '#803E75', '#FF6800', '#A6BDD7', '#C10020', '#CEA262', '#817066', '#007D34', '#F6768E', '#00538A', '#FF7A5C', '#53377A', '#FF8E00', '#B32851', '#F4C800', '#7F180D', '#93AA00', '#593315', '#F13A13', '#232C16');
 
 		// Text
 		$config['size']['tick_mark'] = 10;
@@ -393,7 +394,7 @@ abstract class pts_graph_core
 		{
 			$paint_color = '#f1052d';
 		}
-		else if(strpos($identifier, 'intel ') !== false || strpos($identifier, 'xeon ') !== false || strpos($identifier, 'core i') !== false)
+		else if(strpos($identifier, 'intel ') !== false || strpos($identifier, 'xeon ') !== false || strpos($identifier, 'core i') !== false || strpos($identifier, 'celeron') !== false)
 		{
 			$paint_color = '#0b5997';
 		}
